#!/bin/sh

FLEX_HOME=/usr/lib/flex

#-------------------------------------- Flex 2 SDK

cd flex-2.0.1
mkdir -p doc-pak
cp *.htm doc-pak/

cat >install.sh <<-EOF
	#!/bin/sh
	mkdir -p $FLEX_HOME
	
	cp -r ./asdoc $FLEX_HOME
	cp -r ./bin $FLEX_HOME
	cp -r ./frameworks $FLEX_HOME
	cp -r ./lib $FLEX_HOME
	cp -r ./player $FLEX_HOME
	cp -r ./resources $FLEX_HOME
	
	cat >/usr/bin/mxmlc <<-EOF2
		#!/bin/sh
		export FLEX_HOME=\\\${FLEX_HOME:-$FLEX_HOME}
		\\\$FLEX_HOME/bin/mxmlc "\\\$@"
	EOF2
	
	cat >/usr/bin/asdoc <<-EOF2
		#!/bin/sh
		export FLEX_HOME=\\\${FLEX_HOME:-$FLEX_HOME}
		\\\$FLEX_HOME/bin/asdoc "\\\$@"
	EOF2
	
	cat >/usr/bin/compc <<-EOF2
		#!/bin/sh
		export FLEX_HOME=\\\${FLEX_HOME:-$FLEX_HOME}
		\\\$FLEX_HOME/bin/compc "\\\$@"
	EOF2
	
	cat >/usr/bin/fdb <<-EOF2
		#!/bin/sh
		export FLEX_HOME=\\\${FLEX_HOME:-$FLEX_HOME}
		\\\$FLEX_HOME/bin/fdb "\\\$@"
	EOF2
	
	chmod +x /usr/bin/mxmlc /usr/bin/asdoc /usr/bin/compc /usr/bin/fdb
EOF

chmod +x install.sh

checkinstall \
	--pkgname="flex2-sdk" \
	--pkgversion="2.0.1" \
	--pkgarch="all" \
	--pkglicense="Freeware" \
	--maintainer="Max \<static@brokenfunction\>" \
	--requires="java2-runtime" \
	--install=no --pakdir=../ $* /bin/sh ./install.sh

cd ../

#-------------------------------------- Standalone Player (wine)

mkdir -p flex-saflashplayer-wine
cd flex-saflashplayer-wine

mkdir -p doc-pak
cat >postinstall-pak <<-EOF
	#!/bin/sh
	update-alternatives --install $FLEX_HOME/bin/gflashplayer flex2-flashplayer $FLEX_HOME/bin/flashplayer-debug-wine 10
EOF
cat >preremove-pak <<-EOF
	#!/bin/sh
	update-alternatives --remove flex2-flashplayer $FLEX_HOME/bin/flashplayer-debug-wine
EOF

cat >install.sh <<-EOF
	#!/bin/sh
	mkdir -p $FLEX_HOME/bin
	cat >$FLEX_HOME/bin/flashplayer-debug-wine <<-EOF2
		#!/bin/sh
		FLEX_HOME=\\\${FLEX_HOME:-$FLEX_HOME}
		wine \\\$FLEX_HOME/player/debug/SAFlashPlayer.exe "\\\$@"
	EOF2
	chmod +x $FLEX_HOME/bin/flashplayer-debug-wine
EOF

chmod +x install.sh postinstall-pak preremove-pak

checkinstall \
	--pkgname="flex2-saflashplayer-wine" \
	--pkgversion="2.0.1" \
	--pkgarch="i386" \
	--pkglicense="Public Domain" \
	--maintainer="Max \<static@brokenfunction\>" \
	--requires="dpkg | chkconfig, flex2-sdk, wine" \
	--install=no --pakdir=../ $* /bin/sh ./install.sh
cd ../

#-------------------------------------- Standalone Player (native)

cd flex-saflashplayer
if [ -f "flashplayer" ]; then

mkdir -p doc-pak
cat >postinstall-pak <<-EOF
	#!/bin/sh
	update-alternatives --install $FLEX_HOME/bin/gflashplayer flex2-flashplayer $FLEX_HOME/bin/flashplayer-debug-native 20
EOF
cat >preremove-pak <<-EOF
	#!/bin/sh
	update-alternatives --remove flex2-flashplayer $FLEX_HOME/bin/flashplayer-debug-native
EOF

cat >install.sh <<-EOF
	#!/bin/sh
	mkdir -p $FLEX_HOME/bin
	cp ./flashplayer $FLEX_HOME/bin/flashplayer-debug-native
	chmod +x $FLEX_HOME/bin/flashplayer-debug-native
EOF

chmod +x install.sh postinstall-pak preremove-pak

checkinstall \
	--pkgname="flex2-saflashplayer-native" \
	--pkgversion="2.0.1" \
	--pkgarch="i386" \
	--pkglicense="Freeware" \
	--maintainer="Max \<static@brokenfunction\>" \
	--requires="dpkg | chkconfig, flex2-sdk" \
	--install=no --pakdir=../ $* /bin/sh ./install.sh

fi
cd ../
